#[non_exhaustive]pub enum Error {
FmtError(Error),
Unimplemented(String),
#[non_exhaustive] GlobalVariablesNotEnabled {
example: String,
},
#[non_exhaustive] ResourcesNotEnabled {
example: String,
},
}Expand description
Errors returned by the Rust-generating backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FmtError(Error)
The provided fmt::Write implementation returned an error.
Unimplemented(String)
The Rust backend currently does not support this particular shader functionality.
#[non_exhaustive]GlobalVariablesNotEnabled
To use a shader with private global variables, Config::global_struct() must be set.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]ResourcesNotEnabled
To use a shader with resources, Config::resource_struct() must be set.