Writer

Struct Writer 

pub struct Writer { /* private fields */ }
naga backend allowing you to translate shader code in any language supported by Naga to Rust code.

A Writer stores a Config and data structures that can be reused for writing multiple modules.

Implementations

Source

impl Writer

pub fn new(config: Config) -> Self

Creates a new Writer.

pub fn write( &mut self, out: &mut dyn Write, module: &Module, info: &ModuleInfo, ) -> Result<(), Error>

Converts module to a string of Rust code.

This function’s behavior is independent of prior uses of this Writer.

Errors

Returns an error if the module cannot be represented as Rust or if out returns an error.