Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration/builder for options for Rust code generation.

This configuration allows you to control syntactic characteristics of the output, and also Rust features that have no equivalent in shader languages.

Implementations

Source

impl Config

pub const fn new() -> Self

Creates a Config with default options.

pub fn explicit_types(self, value: bool) -> Self

Sets whether the generated code contains explicit types when they could be omitted.

The default is false.

pub fn raw_pointers(self, value: bool) -> Self

Sets whether the generated code uses raw pointers instead of references.

The resulting code is unsafe and may be unsound if the input module uses pointers incorrectly.

The default is false.

TODO: This should be configurable on a per-function basis.

pub fn public_items(self, value: bool) -> Self

Sets whether generated items have pub visibility instead of private.

The default is false.

pub fn runtime_path(self, value: impl Into<Cow<'static, str>>) -> Self

Sets the Rust module path to the runtime support library.

The default is "::naga_rust_rt".

Panics

May panic if the path is not syntactically valid or not an absolute path.

pub fn global_struct(self, name: impl Into<String>) -> Self

Allow declarations of global variables, generate a struct with the given name to hold them, and make all functions methods of that struct.